
# Jupyter Community Call

## June 25th, 2019

**Date:** June 25th, 2019, at 9am PST (your [timezome](http://arewemeetingyet.com/Los%20Angeles/2019-06-25/09:00/Jupyter%20Community%20Call))

**Link** [Youtube Video](https://youtu.be/27pMFoJd0H4)

**Welcome!**


## Purpose

Think of it as a monthly, virtual JupyterCon. It’s a place to announce and share fun things happening in the Jupyter community.

For more discussion on the format of these calls, see the thread [here](https://discourse.jupyter.org/t/reviving-the-all-jupyter-team-meetings/423).

## Short reports, celebrations, shout-outs

This is a place to make *short* announcements (without a need for discussion). 

* [ ] [name=willingc] Congrats again to our [newest BinderHub/JupyterHub team member, Sarah](https://discourse.jupyter.org/t/welcoming-our-new-jupyterhub-team-member-sarah/1416) :tada: 
* [ ] [name=Zsailer] Welcome the new Jupyter Cal Poly Intern team. 
* [ ] [name=tgeorgeux] Introduction to Rich Context Work: Metadata, Data Registry, Commenting and Annotation, Real-Time Collaboration, Telemetry.
    * [Data Registry/Explorer](https://github.com/jupyterlab/jupyterlab-data-explorer)
    * [Commenting](https://github.com/jupyterlab/jupyterlab-commenting)
    * [Metadata](https://github.com/jupyterlab/jupyterlab-metadata-service)
    * [Telemetry](https://github.com/jupyter/telemetry)
* [ ] [name=Erik Sundell]
    [repo2docker](https://github.com/jupyter/repo2docker) / MyBinder.org support for git repositories with Pipfile / Pipfile.lock coming up soon I hope ;D
    [repo2docker#649](https://github.com/jupyter/repo2docker/pull/649)
    
* [ ] [name=yournamehere]

## Agenda Items

Add agenda items here **before** the meeting. We will reorganize the agenda so that it fits in the 60m meeting slot.

* [ ] [name=kbates] Brief overview of Jupyter Enterprise Gateway
    * Questions: 
        * Where can we find information to share with others?
            *  See this [post](https://blog.jupyter.org/on-demand-notebooks-with-jupyterhub-jupyter-enterprise-gateway-and-kubernetes-e8e423695cbf)
    * Comments:
        * Add talks to EG docs
        * Check if Docker Stacks has a link to the EG docker stacks
        * Add link to this demo to the EG docs
* [ ] [name=dgentry] existing system for git commit+push without requiring a forked repo? Similar to submitting homework for grading?
    * nbgrader and hubshare mentioned by Zach
    * [nbstripout](https://github.com/kynan/nbstripout) / [fastai-nbstripout](https://github.com/fastai/fastai-nbstripout) can play a part of making git merges more reasonable
    * Ask the Jupyter education community 
        * [Jupyter Education Mailing List](https://jupyter.org/community)
    * Check out solutions from [Gigantum](https://gigantum.com/), a tech company started out of Johns Hopkins
* [ ] [name=YourNameHere]
* [ ] [name=YourNameHere]

## Attendees

If you are joining the Jupyter Community Call, sign in below so we know who was here.

- Zach    | Jupyter Cal Poly          | @Zsailer        |
- Erik    | Sandvik                   | @consideRatio   |
- Denton  | individual                | @DentonGentry   |
- Tim     | Jupyter Cal Poly          | @tgeorgeux      |
- Kevin   | IBM                       | @kevin-bates    |
- Wayne   | Upstate Medical University| @Fomightez      |
- Dav     | Gigantum                  | @davclark       |
- Mike Trizna  | Smithsonian          | @MikeTrizna     |
- Anton Akhmerov   | TU Delft | @akhmerov |
- Markelle   |  Jupyter Cal Poly      |       |
- Carol   | Jupyter   |      @willingc |
- Saul | Quansight | @saulshanabrook | 
- Yair    | Mavenomics                | @YairMarcowMavenomics|
- Joe     | Mavenomics                | @quigleyj-mavenomics|
- Ruixin     | Microsoft              | @ruixinxu            |